Method: Amazon::AWS::ItemLookup#initialize
- Defined in:
- lib/amazon/aws.rb
#initialize(id_type, parameters) ⇒ ItemLookup
Look up a specific item in the AWS catalogue. id_type is the type of identifier and parameters is a hash that identifies the item to be located and narrows the scope of the search.
Example:
il = ItemLookup.new( 'ASIN', { 'ItemId' => 'B000AE4QEC'
‘MerchantId’ => ‘Amazon’ } )
In the above example, we search for an item, based on its ASIN. The use of MerchantId restricts the offers returned to those for sale by Amazon (as opposed to third-party sellers).
985 986 987 |
# File 'lib/amazon/aws.rb', line 985 def initialize(id_type, parameters) super( { 'IdType' => id_type }.merge( parameters ) ) end |